==> kosmindoormap-24.08.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KOSMIndoorMap/KOSMIndoorMapTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KOSM" for configuration ""
set_property(TARGET KOSM APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KOSM PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKOSM.so.24.08.0"
  IMPORTED_SONAME_NOCONFIG "libKOSM.so.1"
  )

list(APPEND _cmake_import_check_targets KOSM )
list(APPEND _cmake_import_check_files_for_KOSM "${_IMPORT_PREFIX}/lib/libKOSM.so.24.08.0" )

# Import target "KOSMIndoorMap" for configuration ""
set_property(TARGET KOSMIndoorMap APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KOSMIndoorMap PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KOpeningHours"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKOSMIndoorMap.so.24.08.0"
  IMPORTED_SONAME_NOCONFIG "libKOSMIndoorMap.so.1"
  )

list(APPEND _cmake_import_check_targets KOSMIndoorMap )
list(APPEND _cmake_import_check_files_for_KOSMIndoorMap "${_IMPORT_PREFIX}/lib/libKOSMIndoorMap.so.24.08.0" )

# Import target "KOSMIndoorRouting" for configuration ""
set_property(TARGET KOSMIndoorRouting APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KOSMIndoorRouting PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "RecastNavigation::Recast;RecastNavigation::Detour"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKOSMIndoorRouting.so.24.08.0"
  IMPORTED_SONAME_NOCONFIG "libKOSMIndoorRouting.so.1"
  )

list(APPEND _cmake_import_check_targets KOSMIndoorRouting )
list(APPEND _cmake_import_check_files_for_KOSMIndoorRouting "${_IMPORT_PREFIX}/lib/libKOSMIndoorRouting.so.24.08.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kosmindoormap-24.08.3-2-aarch64.pkg.tar.xz: usr/lib/cmake/KOSMIndoorMap/KOSMIndoorMapTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KOSM" for configuration ""
set_property(TARGET KOSM APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KOSM PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKOSM.so.24.08.3"
  IMPORTED_SONAME_NOCONFIG "libKOSM.so.1"
  )

list(APPEND _cmake_import_check_targets KOSM )
list(APPEND _cmake_import_check_files_for_KOSM "${_IMPORT_PREFIX}/lib/libKOSM.so.24.08.3" )

# Import target "KOSMIndoorMap" for configuration ""
set_property(TARGET KOSMIndoorMap APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KOSMIndoorMap PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt6::Network;KOpeningHours"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKOSMIndoorMap.so.24.08.3"
  IMPORTED_SONAME_NOCONFIG "libKOSMIndoorMap.so.1"
  )

list(APPEND _cmake_import_check_targets KOSMIndoorMap )
list(APPEND _cmake_import_check_files_for_KOSMIndoorMap "${_IMPORT_PREFIX}/lib/libKOSMIndoorMap.so.24.08.3" )

# Import target "KOSMIndoorRouting" for configuration ""
set_property(TARGET KOSMIndoorRouting APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KOSMIndoorRouting PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "RecastNavigation::Recast;RecastNavigation::Detour"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKOSMIndoorRouting.so.24.08.3"
  IMPORTED_SONAME_NOCONFIG "libKOSMIndoorRouting.so.1"
  )

list(APPEND _cmake_import_check_targets KOSMIndoorRouting )
list(APPEND _cmake_import_check_files_for_KOSMIndoorRouting "${_IMPORT_PREFIX}/lib/libKOSMIndoorRouting.so.24.08.3" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
